from enum import Enum


class RunStatusDto(str, Enum):
    COMPLETED = "COMPLETED"
    ERROR_CLIENT = "ERROR_CLIENT"
    ERROR_REJECTED = "ERROR_REJECTED"
    ERROR_RETRY_LIMIT_EXCEEDED = "ERROR_RETRY_LIMIT_EXCEEDED"
    ERROR_SERVER = "ERROR_SERVER"
    ERROR_TIMEOUT = "ERROR_TIMEOUT"
    PAUSED_FOR_INPUT = "PAUSED_FOR_INPUT"
    QUEUED = "QUEUED"
    QUEUED_FOR_RESUME = "QUEUED_FOR_RESUME"
    RUNNING = "RUNNING"

    def __str__(self) -> str:
        return str(self.value)
